Crate kcr_secrets_hashicorp_com

Crate kcr_secrets_hashicorp_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the secrets.hashicorp.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

secrets.hashicorp.com/v1beta1

  • HCPAuth
  • HCPVaultSecretsApp
  • VaultAuth
  • VaultConnection
  • VaultDynamicSecret
  • VaultPKISecret
  • VaultStaticSecret

Modules

v1beta1